@@ -84,7 +84,7 @@ M. E. Tuckerman, J. Alejandre, R. López-Rendón, A. L Jochim, and G. J. Martyna
 J. Phys. A: Math. Gen. 39 5629 (2006)
 
 As such, we define several primitives that are generically useful in describing
-simulations of this type. Namely, the velocity-verlet integration step that is
+simulations of this type. Namely, the velocity-Verlet integration step that is
 used in the NVE and NVT simulations. We also define a general Nose-Hoover chain
 primitive that is used to couple components of the system to a chain that
 regulates the temperature. These primitives can be combined to construct more
@@ -97,7 +97,7 @@ def velocity_verlet(force_fn: Callable[..., Array],
                     dt: float,
                     state: T,
                     **kwargs) -> T:
-  """Apply a single step of velocity verlet integration to a state."""
+  """Apply a single step of velocity Verlet integration to a state."""
   dt = f32(dt)
   dt_2 = f32(dt / 2)
   dt2_2 = f32(dt ** 2 / 2)
@@ -150,7 +150,7 @@ def nve(energy_or_force_fn: Callable[..., Array],
 
   Samples from the microcanonical ensemble in which the number of particles
   (N), the system volume (V), and the energy (E) are held constant. We use a
-  standard velocity verlet integration scheme.
+  standard velocity Verlet integration scheme.
 
   Args:
     energy_or_force: A function that produces either an energy or a force from
@@ -252,15 +252,15 @@ def nose_hoover_chain(dt: float,
   timescale than the rest of the simulation. Therefore, it sometimes necessary
   to integrate the chain over several substeps for each step of MD. To do this
   we follow the Suzuki-Yoshida scheme. Specifically, we subdivide our chain
-  simulation into $n_c$ substeps. These substeps are further subdivided into
-  $n_sy$ steps. Each $n_sy$ step has length $\delta_i = \Delta t w_i / n_c$
-  where $w_i$ are constants such that $\sum_i w_i = 1$. See the table of
+  simulation into :math:`n_c` substeps. These substeps are further subdivided into
+  :math:`n_sy` steps. Each :math:`n_sy` step has length :math:`\delta_i = \Delta t w_i / n_c`
+  where :math:`w_i` are constants such that :math:`\sum_i w_i = 1`. See the table of
   Suzuki_Yoshida weights above for specific values. The number of substeps
   and the number of Suzuki-Yoshida steps are set using the `chain_steps` and
   `sy_steps` arguments.
 
   Consequently, the Nose-Hoover chains are described by three functions: an
-  `init_fn` that initializes the state of the chian, a `half_step_fn` that
+  `init_fn` that initializes the state of the chain, a `half_step_fn` that
   updates the chain for one half-step, and an `update_chain_mass_fn` that
   updates the masses of the chain to enforce the correct period of oscillation.
 
@@ -274,7 +274,7 @@ def nose_hoover_chain(dt: float,
       simulation.
     chain_length: An integer specifying the number of particles in
       the Nose-Hoover chain.
-    chain_steps: An integer specifying the number, $n_c$, of outer substeps.
+    chain_steps: An integer specifying the number, :math:`n_c`, of outer substeps.
     sy_steps: An integer specifying the number of Suzuki-Yoshida steps. This
       must be either 1, 3, 5, or 7.
     tau: A floating point timescale over which temperature equilibration occurs.
@@ -428,12 +428,12 @@ def nvt_nose_hoover(energy_or_force_fn: Callable[..., Array],
       and dR should be ndarrays of shape [n, spatial_dimension].
     dt: Floating point number specifying the timescale (step size) of the
       simulation.
-    kT: Floating point number specifying the temperature inunits of Boltzmann
+    kT: Floating point number specifying the temperature in units of Boltzmann
       constant. To update the temperature dynamically during a simulation one
       should pass `kT` as a keyword argument to the step function.
     chain_length: An integer specifying the number of particles in
       the Nose-Hoover chain.
-    chain_steps: An integer specifying the number, $n_c$, of outer substeps.
+    chain_steps: An integer specifying the number, :math:`n_c`, of outer substeps.
     sy_steps: An integer specifying the number of Suzuki-Yoshida steps. This
       must be either 1, 3, 5, or 7.
     tau: A floating point timescale over which temperature equilibration occurs.
@@ -684,26 +684,27 @@ def npt_nose_hoover(energy_fn: Callable[..., Array],
                 **kwargs):
     N, dim = position.shape
 
-    def U(vol):
-      return energy_fn(position, box=box_fn(vol), **kwargs)
+    def U(eps):
+      return energy_fn(position, box=box_fn(vol), perturbation=(1+eps), **kwargs)
 
     dUdV = grad(U)
     KE2 = util.high_precision_sum(velocity ** 2 * mass)
     R = space.transform(box_fn(vol), position)
     RdotF = util.high_precision_sum(R * force)
 
-    return alpha * KE2 + RdotF - dim * vol * dUdV(vol) - pressure * vol * dim
+    return alpha * KE2 + RdotF - dUdV(0.0) - pressure * vol * dim
 
   def sinhx_x(x):
     """Taylor series for sinh(x) / x as x -> 0."""
-    return 1 + x ** 2 / 6 + x ** 4 / 120
+    return (1 + x ** 2 / 6 + x ** 4 / 120 + x ** 6 / 5040 +
+            x ** 8 / 362_880 + x ** 10 / 39_916_800)
 
   def exp_iL1(box, R, V, V_b, **kwargs):
     x = V_b * dt
     x_2 = x / 2
     sinhV = sinhx_x(x_2)  # jnp.sinh(x_2) / x_2
-    return shift_fn(R * jnp.exp(x), dt * V * jnp.exp(x_2) * sinhV, box=box,
-                    **kwargs)  # pytype: disable=wrong-keyword-args
+    return shift_fn(R, R * (jnp.exp(x) - 1) + dt * V * jnp.exp(x_2) * sinhV,
+                    box=box, **kwargs)  # pytype: disable=wrong-keyword-args
 
   def exp_iL2(alpha, V, A, V_b):
     x = alpha * V_b * dt_2
@@ -829,7 +830,7 @@ class NVTLangevinState:
       shape [n, spatial_dimension].
     velocity: The velocity of particles. An ndarray of floats with shape
       [n, spatial_dimension].
-    force: The (non-stochistic) force on particles. An ndarray of floats with
+    force: The (non-stochastic) force on particles. An ndarray of floats with
       shape [n, spatial_dimension].
     mass: The mass of particles. Will either be a float or an ndarray of floats
       with shape [n].
@@ -867,7 +868,7 @@ def nvt_langevin(energy_or_force: Callable[..., Array],
       and dR should be ndarrays of shape [n, spatial_dimension].
     dt: Floating point number specifying the timescale (step size) of the
       simulation.
-    kT: Floating point number specifying the temperature inunits of Boltzmann
+    kT: Floating point number specifying the temperature in units of Boltzmann
       constant. To update the temperature dynamically during a simulation one
       should pass `kT` as a keyword argument to the step function.
     gamma: A float specifying the friction coefficient between the particles
@@ -968,7 +969,7 @@ def brownian(energy_or_force: Callable[..., Array],
       and dR should be ndarrays of shape [n, spatial_dimension].
     dt: Floating point number specifying the timescale (step size) of the
       simulation.
-    kT: Floating point number specifying the temperature inunits of Boltzmann
+    kT: Floating point number specifying the temperature in units of Boltzmann
       constant. To update the temperature dynamically during a simulation one
       should pass `kT` as a keyword argument to the step function.
     gamma: A float specifying the friction coefficient between the particles
